#!/bin/bash

MA_PIDFILE=/var/opt/novell/messenger/temp/nmma.pid
AA_PIDFILE=/var/opt/novell/messenger/temp/nmaa.pid
NDSCONF=/etc/nds.conf
STARTUP_DIR=/etc/opt/novell/messenger
STARTUP_MA=$STARTUP_DIR/strtup.ma
SCHERR_DIR=/var/opt/novell/log/messenger
SCHERR_FILE=${SCHERR_DIR}/nmschema.err
CONFIGURE_SCRIPT=/opt/novell/messenger/configure.sh
RPM_DIR=.

# Messenger packages
PKG_RELEASE=20050830

AGNT_PKG=novell-messenger-agents
AGNT_VRSN=1.0.5
AGNT_PKG_VRSN=${AGNT_PKG}-${AGNT_VRSN}-${PKG_RELEASE}
AGNT_RPM=${AGNT_PKG_VRSN}.i386.rpm

C1ADMIN_PKG=novell-messenger-c1admin
C1ADMIN_VRSN=1.0.5
C1ADMIN_PKG_VRSN=${C1ADMIN_PKG}-${C1ADMIN_VRSN}-${PKG_RELEASE}
C1ADMIN_RPM=${C1ADMIN_PKG_VRSN}.i386.rpm

# LDAP packages
LDAPBASE_PKG=NLDAPbase
LDAPSDK_PKG=NLDAPsdk
LDAP_VRSN=8.7.1-1
LDAPBASE_PKG_VRSN=${LDAPBASE_PKG}-${LDAP_VRSN}
LDAPSDK_PKG_VRSN=${LDAPSDK_PKG}-${LDAP_VRSN}
LDAP_BASE_RPM=${LDAPBASE_PKG_VRSN}.i386.rpm
LDAP_SDK_RPM=${LDAPSDK_PKG_VRSN}.i386.rpm

# gettext setup
TEXTDOMAIN=install
TEXTDOMAINDIR=${PWD}/locale

function askYesOrNo
{
	REPLY=""
	while [ -z "$REPLY" ] ; do
		read -ep "$1 $YES_NO_PROMPT" REPLY
		REPLY=$(echo ${REPLY}|tr [:lower:] [:upper:])
		case $REPLY in
			$YES_CAPS ) return 0 ;;
			$NO_CAPS ) return 1 ;;
			* ) REPLY=""
		esac
	done
}

function checkRequired
{
	# Check that libstdc++.so.5 is installed
	if [ ! -f /usr/lib/libstdc++.so.5 ] ; then
		echo $"Missing required library libstdc++.so.5."
		echo $"Download and install the libstdc++.so.5 RPM before installing Messenger."
		echo
		return 1
	fi

	return 0
}

function checkForLDAP
{

	# Check to see if LDAP needs to be installed
	if ! rpm -q $LDAPSDK_PKG > /dev/null 2>&1 ; then
		g_binstallldap=1
	else
		# Check to see if our version is newer
		if [ $(rpm -q $LDAPSDK_PKG) \< $LDAPSDK_PKG_VRSN ] ; then
			if askYesOrNo $"Install has a newer version of the Novell LDAP SDK, do you want to install it?" ; then
				g_bupdateldap=1
			fi
		fi
	fi
}

function checkForMessenger
{
	# Check to see if agents package is already installed
	if ! rpm -q $AGNT_PKG > /dev/null 2>&1 ; then
		g_binstallagents=1
	else
		# Check the version
		if rpm -q $AGNT_PKG_VRSN > /dev/null 2>&1 ; then
			echo $"The package $AGNT_PKG_VRSN is already installed."
			if askYesOrNo $"Do you want to remove it and then reinstall it?" ; then
				g_breinstallagents=1
			fi
			echo
		else
			g_bupdateagents=1
		fi
	fi

	# Is ConsoleOne installed
	if [ -f /usr/ConsoleOne/bin/ConsoleOne ] ; then

		# Check to see if c1admin package is installed
		if ! rpm -q $C1ADMIN_PKG > /dev/null 2>&1 ; then
			g_binstallc1admin=1
		else
			# Check the version
			if rpm -q $C1ADMIN_PKG_VRSN > /dev/null 2>&1 ; then
				echo $"The package $C1ADMIN_PKG_VRSN is already installed."
				if askYesOrNo $"Do you want to remove it and then reinstall it?" ; then
					g_breinstallc1admin=1
				fi
			else
				g_bupdatec1admin=1
			fi
		fi

	else
		echo $"Cannot find ConsoleOne installation. Not installing $C1ADMIN_PKG."
	fi

}

function installLDAPFiles
{
	if [ $g_binstallldap -eq 1 ] ; then
		echo $"Installing package $LDAPSDK_PKG_VRSN"
		if ! rpm -ih ${RPM_DIR}/${LDAP_SDK_RPM} ; then
			echo $"Failed to install LDAP RPMs. Aborting install."
			exit 1
		fi

		echo $"Installing package $LDAPBASE_PKG_VRSN"
		if ! rpm -ih ${RPM_DIR}/${LDAP_BASE_RPM} ; then
			echo $"Failed to install LDAP RPMs. Aborting install."
			exit 1
		fi
	elif [ $g_bupdateldap -eq 1 ] ; then
		echo $"Updating package $LDAPSDK_PKG to version $LDAP_VRSN"
		if ! rpm -Fh ${RPM_DIR}/${LDAP_SDK_RPM} ; then
			echo $"Failed to update LDAP RPMs. Aborting install."
			exit 1
		fi

		echo $"Updating package $LDAPBASE_PKG to version $LDAP_VRSN"
		if ! rpm -Fh ${RPM_DIR}/${LDAP_BASE_RPM} ; then
			echo $"Failed to update LDAP RPMs. Aborting install."
			exit 1
		fi
	fi
}

function installMessengerFiles
{
	# Install the files
	if [ $g_breinstallagents -eq 1 ] ; then
		echo $"Reinstalling package $AGNT_PKG_VRSN"
		if ! rpm -e $AGNT_PKG_VRSN > /dev/null 2>&1 || \
		   ! rpm -ih ${RPM_DIR}/$AGNT_RPM ; then
			echo $"Failed to reinstall messenger agents RPM. Aborting install."
			exit 1
		fi
	elif [ $g_binstallagents -eq 1 ] ; then
		echo $"Installing package $AGNT_PKG_VRSN"
		if ! rpm -ih ${RPM_DIR}/$AGNT_RPM ; then
			echo $"Failed to install messenger agents RPM. Aborting install."
			exit 1
		fi
	elif [ $g_bupdateagents -eq 1 ] ; then
		echo $"Updating package $AGNT_PKG to version $AGNT_VRSN"
		if ! rpm -Fh ${RPM_DIR}/$AGNT_RPM ; then
			echo $"Failed to update messenger agents RPM. Aborting install."
			exit 1
		fi

	fi

	# Install snapins
	if [ $g_breinstallc1admin -eq 1 ] ; then
		echo $"Reinstalling package $C1ADMIN_PKG_VRSN"
		if ! rpm -e $C1ADMIN_PKG_VRSN > /dev/null 2>&1 || \
		   ! rpm -ih ${RPM_DIR}/${C1ADMIN_RPM} ; then
			echo $"Failed to reinstall $C1ADMIN_PKG_VRSN. Aborting install."
			exit 1
		fi
	elif [ $g_binstallc1admin -eq 1 ] ; then
		echo $"Installing package $C1ADMIN_PKG_VRSN"
		if ! rpm -ih ${RPM_DIR}/$C1ADMIN_RPM ; then
			echo $"Failed to install $C1ADMIN_PKG_VRSN. Aborting install."
			exit 1
		fi
	elif [ $g_bupdatec1admin -eq 1 ] ; then
		echo $"Updating package $C1ADMIN_PKG to version $C1ADMIN_VRSN"
		if ! rpm -Fh ${RPM_DIR}/$C1ADMIN_RPM ; then
			echo $"Failed to update $C1ADMIN_PKG_VRSN. Aborting install."
			exit 1
		fi
	fi

}

function installClientFiles
{
	mkdir -p /opt/novell/messenger/software/client/xplat

	# Copy the client files for Mac/Linux if they are in the image
	if [ -d ../client/xplat/linux ] ; then

		# remove old backup
		if [ -d /opt/novell/messenger/software/client/xplat/linux.old ] ; then
			rm -rf /opt/novell/messenger/software/client/xplat/linux.old
		fi

		# Move old clients out of the way
		dir="/opt/novell/messenger/software/client/linux" # This is to move SP2 and prior installations
		if [ -d "$dir" ] ; then
			mv $dir /opt/novell/messenger/software/client/xplat/linux.old
		fi

		dir="/opt/novell/messenger/software/client/xplat/linux" # This is to move SP3 and later installations
		if [ -d "$dir" ] ; then
			mv $dir ${dir}.old
		fi

		mkdir -p $dir
		cp -rp ../client/xplat/linux/* $dir
	fi

	if [ -d ../client/xplat/mac ] ; then

		# remove old backup
		if [ -d /opt/novell/messenger/software/client/xplat/mac.old ] ; then
			rm -rf /opt/novell/messenger/software/client/xplat/mac.old
		fi

		# Move old clients out of the way
		dir="/opt/novell/messenger/software/client/mac" # This is to move SP2 and prior installations
		if [ -d "$dir" ] ; then
			mv $dir /opt/novell/messenger/software/client/xplat/mac.old
		fi

		dir="/opt/novell/messenger/software/client/xplat/mac" # This is to move SP3 and later installations
		if [ -d "$dir" ] ; then
			mv $dir ${dir}.old
		fi

		mkdir -p $dir
		cp -rp ../client/xplat/mac/* $dir
	fi

	if [ -d ../client/win32 ] ; then

		# remove old backup
		if [ -d /opt/novell/messenger/software/client/win32.old ] ; then
			rm -rf /opt/novell/messenger/software/client/win32.old
		fi

		# Move old client out of the way
		dir="/opt/novell/messenger/software/client/win32"
		if [ -d "$dir" ] ; then
			mv $dir ${dir}.old
		fi

		mkdir -p $dir
		cp -rp ../client/win32/* $dir
	fi
}

function newScreen
{
	clear
#	echo
}

function showEULA
{
	local file

	echo $"Welcome to the GroupWise Messenger Server Install."
	echo
	echo $"The GroupWise Messenger documentation is located at /server/docs on the CD."
	echo $"The documents contain important information that you should read before installing."
	echo
    echo $"The GroupWise Messenger Delano End User License Agreement will now be displayed."
    echo $"Please read the agreement carefully before accepting the terms."
    echo $"Press ENTER to continue."
    read
    echo

	unicode=""
	if cat /etc/SuSE-release | grep 'SLES-8' >/dev/null 2>&1; then
		unicode="_uni"
	fi

	lang=$(echo $LANG|cut -f1 -d '_' -)
	file=./license${lang}${unicode}.txt
	if [ -f $file ] ; then
		more $file
	else
		more ./licenseen${unicode}.txt
	fi

    if ! askYesOrNo $"Do you accept all the terms of the preceding license agreement?" ; then
		echo $"Installation cannot proceed without acceptance of License Agreement."
		exit 1
    fi
}

function showInstallSummary
{
	if [ "$g_breinstallagents" -eq 1 ] || \
		[ "$g_binstallagents" -eq 1 ] || \
		[ "$g_bupdateagents" -eq 1 ] || \
		[ "$g_breinstallc1admin" -eq 1 ] || \
		[ "$g_binstallc1admin" -eq 1 ] || \
		[ "$g_bupdatec1admin" -eq 1 ] || \
		[ "$g_binstallldap" -eq 1 ] || \
		[ "$g_bupdateldap" -eq 1 ] ; then
		echo
		echo $"The following packages will now be installed:"
	else
		echo
		echo $"The Messenger RPMs have already been installed."
		echo $"There are no new packages to install."
		return 1
	fi

	if [ "$g_breinstallagents" -eq 1 ] || [ "$g_binstallagents" -eq 1 ] || [ "$g_bupdateagents" -eq 1 ] ; then
		echo "$AGNT_PKG_VRSN"
	fi

	if [ "$g_breinstallc1admin" -eq 1 ] || [ "$g_binstallc1admin" -eq 1 ] || [ "$g_bupdatec1admin" -eq 1 ] ; then
		echo "$C1ADMIN_PKG_VRSN"
	fi

	if [ "$g_binstallldap" -eq 1 ] || [ "$g_bupdateldap" -eq 1 ] ; then
		echo "$LDAPSDK_PKG_VRSN"
		echo "$LDAPBASE_PKG_VRSN"
	fi

	echo
	if ! askYesOrNo $"Continue with installation?" ; then
		exit 0
	fi

	return 0
}

########################################################
# Main script
########################################################


# Check for root privileges
if [ $(id -u) -ne 0 ] ; then
	echo $"You must be root to run this script"
	exit 1
fi

# Initialize the yes/no prompt
YES_STRING=$"y"
NO_STRING=$"n"
YES_NO_PROMPT=$"[y/n]: "
YES_CAPS=$(echo ${YES_STRING}|tr [:lower:] [:upper:])
NO_CAPS=$(echo ${NO_STRING}|tr [:lower:] [:upper:])

newScreen
showEULA
newScreen

g_binstallldap=0
g_bupdateldap=0
g_binstallagents=0
g_breinstallagents=0
g_bupdateagents=0
g_breinstallc1admin=0
g_binstallc1admin=0
g_bupdatec1admin=0

echo $"Checking for packages to install..."
echo

if ! checkRequired ; then
	exit 1
fi

#checkForLDAP
checkForMessenger

showInstallSummary
if [ "$?" -eq 0 ] ; then
	newScreen
#	installLDAPFiles
	installMessengerFiles
	installClientFiles
fi

# Run configuration script
echo
if ! askYesOrNo $"Do you want to configure your Messenger system now?" ; then
	echo
	echo $"You must run $CONFIGURE_SCRIPT to configure your Messenger system."
	echo $"The agents will not run until they are configured."
else
	. $CONFIGURE_SCRIPT
fi

echo $"Installation complete."
exit 0
